# boa_web
A GUI application development platform that allows use of web technologies like CSS, HTML and Javascript. Python analogue to electron.js. Similar to eel but based on cefpython3 instead, to provide greater control over the browser.

NOTE: Using the set-icon feature requires installation of [xseticon](https://github.com/xeyownt/xseticon)